# coding: utf-8
from __future__ import absolute_import

from m3_ext.ui.base import ExtUIComponent


class BaseExtControl(ExtUIComponent):
    """
    Базовый класс для кнопочных контролов
    """
    def __init__(self, *args, **kwargs):
        super(BaseExtControl, self).__init__(*args, **kwargs)

    def _make_read_only(
            self, access_off=True, exclude_list=(), *args, **kwargs):
        # TODO: Нахера тут переопределение, если в базовом классе тоже самое?
        # Описание в базовом классе ExtUiComponent.
        raise NotImplementedError()



# coding: utf-8
"""
В данный пакет включаются контейнерные компоненты
"""
from __future__ import absolute_import

from .container_complex import ExtContainerTable
from .containers import ExtContainer
from .containers import ExtCountFreePagingBar
from .containers import ExtPagingBar
from .containers import ExtRadioGroup
from .containers import ExtToolBar
from .containers import ExtToolbarMenu
from .context_menu import ExtContextMenu
from .context_menu import ExtContextMenuItem
from .forms import ExtFieldSet
from .forms import ExtForm
from .forms import ExtPanel
from .forms import ExtTabPanel
from .forms import ExtTitlePanel
from .grids import ExtGrid
from .grids import ExtGridBooleanColumn
from .grids import ExtGridCellSelModel
from .grids import ExtGridCheckBoxSelModel
from .grids import ExtGridCheckColumn
from .grids import ExtGridColumn
from .grids import ExtGridDateColumn
from .grids import ExtGridLockingColumnModel
from .grids import ExtGridLockingView
from .grids import ExtGridNumberColumn
from .grids import ExtGridRowSelModel
from .trees import ExtTree
from .trees import ExtTreeNode
